@@ -66,6 +66,7 @@ pub struct Config {
     pub uda_background_process: String,
     pub uda_background_process_period: usize,
     pub uda_task_report_prompt_on_delete: bool,
+    pub uda_task_report_prompt_on_done: bool,
 }
 
 impl Config {
@@ -111,6 +112,7 @@ impl Config {
         let uda_style_report_completion_pane =
             uda_style_report_completion_pane.unwrap_or_else(|| Style::default().bg(Color::Rgb(223, 223, 223)));
         let uda_task_report_prompt_on_delete = Self::get_uda_task_report_prompt_on_delete(data);
+        let uda_task_report_prompt_on_done = Self::get_uda_task_report_prompt_on_done(data);
 
         Ok(Self {
             enabled,
@@ -144,6 +146,7 @@ impl Config {
             uda_background_process,
             uda_background_process_period,
             uda_task_report_prompt_on_delete,
+            uda_task_report_prompt_on_done,
         })
     }
 
@@ -186,7 +189,7 @@ impl Config {
                 let attribute = i.next();
                 let line = i.collect::<Vec<_>>().join(" ");
                 let line = line.trim_start_matches(' ');
-                let tcolor = Self::get_tcolor(&line);
+                let tcolor = Self::get_tcolor(line);
                 if let Some(attr) = attribute {
                     color_collection.insert(attr.to_string(), tcolor);
                 };
@@ -451,6 +454,13 @@ impl Config {
             .unwrap_or(true)
     }
 
+    fn get_uda_task_report_prompt_on_done(data: &str) -> bool {
+        Self::get_config("uda.taskwarrior-tui.task-report.prompt-on-done", data)
+            .unwrap_or_default()
+            .get_bool()
+            .unwrap_or(false)
+    }
+
     fn get_uda_task_report_prompt_on_delete(data: &str) -> bool {
         Self::get_config("uda.taskwarrior-tui.task-report.prompt-on-delete", data)
             .unwrap_or_default()
